@@ -3,6 +3,11 @@ mod hyper;
 #[cfg(feature = "hyper-requester")]
 pub use hyper::*;
 
+#[cfg(feature = "reqwest-requester")]
+mod reqwest;
+#[cfg(feature = "reqwest-requester")]
+pub use reqwest::*;
+
 use async_trait::async_trait;
 use std::collections::HashMap;
 
